@@ -475,13 +475,21 @@ class ContractRedemption:
 
     @property
     def hedge_gain_oracleUnits(self) -> OracleUnit:
+        # Note that this is not the same as (end sats - start sats) * end price. start value depends on start price.
         # Note that we use naive end price. This represents reality of slippage in liquidations.
-        return self.base_funding.base_proposal.oracle_unit_cls(self.hedge_gain_sats.bch * float(self.naive_end_price_oracleUnits_per_bch))
+        payout_oracleUnits = self.hedge_payout_oracleUnits
+        input_oracleUnits = self.base_funding.base_proposal.hedge_input_oracleUnits
+        fee_oracleUnits = self.base_funding.fee_oracleUnits_to_hedge
+        return self.base_funding.base_proposal.oracle_unit_cls(payout_oracleUnits - input_oracleUnits + fee_oracleUnits)
 
     @property
     def long_gain_oracleUnits(self) -> OracleUnit:
+        # Note that this is not the same as (end sats - start sats) * end price. start value depends on start price.
         # Note that we use naive end price. This represents reality of slippage in liquidations.
-        return self.base_funding.base_proposal.oracle_unit_cls(self.long_gain_sats.bch * float(self.naive_end_price_oracleUnits_per_bch))
+        payout_oracleUnits = self.long_payout_oracleUnits
+        input_oracleUnits = self.base_funding.base_proposal.long_input_oracleUnits
+        fee_oracleUnits = self.base_funding.fee_oracleUnits_to_long
+        return self.base_funding.base_proposal.oracle_unit_cls(payout_oracleUnits - input_oracleUnits + fee_oracleUnits)
 
     ###############
     # Relative gains
