@@ -24,32 +24,47 @@ ORACLE_MAX_PRICE = (2 ** 31) - 1
 GENERIC_4_BYTE_NUMBER = 2 ** 30
 
 
-@dataclass(frozen=False)
+@dataclass(frozen=True)
 class StrictPricepoints:
     """Sorted, unique pricepoints all from the same oracle"""
-    all: Sequence[Pricepoint, ...]
+    all: tuple[Pricepoint, ...]
 
     def __post_init__(self):
+        self._validate_pricepoints(self.all)
+
+    @classmethod
+    def new(cls, pricepoints: Sequence[Pricepoint]):
+        sorted_pricepoints = cls._sort_pricepoints(pricepoints)
+        cls._validate_pricepoints(sorted_pricepoints)
+        return cls(sorted_pricepoints)
+
+    @classmethod
+    def _validate_pricepoints(cls, pricepoints: Sequence[Pricepoint]):
         # first validate oracle pubkeys (definitely die if mixed oracles)
-        if self.all:
-            oracle_pubkey = self.all[0].oracle_pubkey
-            for p in self.all:
+        if pricepoints:
+            oracle_pubkey = pricepoints[0].oracle_pubkey
+            for p in pricepoints:
                 validators.equal(p.oracle_pubkey, oracle_pubkey)
 
         # enforce uniqueness by timestamp
         lookup = {}
-        for p in self.all:
+        for p in pricepoints:
             existing = lookup.get(p.timestamp)
             if existing is None:
                 lookup[p.timestamp] = p
             else:
                 if p == existing:
-                    pass  # it's just a duplicate
+                    raise ValueError(f'duplicate pricepoint in sequence: {p}')
                 else:
                     raise ValueError(f'same timestamp, same oracle, different value: {p} vs {existing}')
 
-        # enforce sorting
-        self.all = tuple(sorted(lookup.values(), key=lambda p: p.timestamp))
+        # enforce sorting. not efficient but performance is not yet an issue
+        sorted_pricepoints = cls._sort_pricepoints(pricepoints)
+        validators.equal(tuple(pricepoints), sorted_pricepoints)
+
+    @staticmethod
+    def _sort_pricepoints(pricepoints: Sequence[Pricepoint]) -> tuple[Pricepoint]:
+        return tuple(sorted(pricepoints, key=lambda p: p.timestamp))
 
     def __str__(self):
         return f'StrictPricepoints: {len(self.all)} prices for {self.all[0].oracleUnit_name}'
