@@ -6,7 +6,7 @@ class Role(str, Enum):
     MAKER = 'Maker'
     TAKER = 'Taker'
     SETTLEMENT_SERVICE = 'Settlement Service'
-    # OTHER = 'Other'
+    OTHER = 'Other'
 
     def __str__(self):
         return self.value
