@@ -203,11 +203,13 @@ TOTAL_FEES_TO_MAKER_SATS = Sats(
     + FEE_100000_TAKER_TO_MAKER.amount_sats
     + FEE_200000_TAKER_TO_MAKER.amount_sats
 )
+DERIVED_TOTAL_FEES_TO_MAKER_ORACLE_UNITS = UsdEM2Beta(TOTAL_FEES_TO_MAKER_SATS * START_PRICE_USDEM2_PER_BCH / SATS_PER_BCH)
 TOTAL_FEES_TO_TAKER_SATS = Sats(
     - FEE_100000_TAKER_TO_MAKER.amount_sats
     - FEE_200000_TAKER_TO_MAKER.amount_sats
     - FEE_400000_TAKER_TO_SETTLEMENT_SERVICE.amount_sats
 )
+DERIVED_TOTAL_FEES_TO_TAKER_ORACLE_UNITS = UsdEM2Beta(TOTAL_FEES_TO_TAKER_SATS * START_PRICE_USDEM2_PER_BCH / SATS_PER_BCH)
 
 
 def standard_contract_funding(proposal: ContractProposal | None = None) -> ContractFunding:
@@ -438,37 +440,37 @@ class TestNewRedemptionDerivedValues(unittest.TestCase):
     def test_gain_oracleUnits(self):
         # Hedge Maker / Long Taker
         expected_gain_oracleUnits_to_hedge_maker_at_redemption = UsdEM2Beta(
-            (DERIVED_HEDGE_PAYOUT_SATS - DERIVED_HEDGE_INPUT_SATS + TOTAL_FEES_TO_MAKER_SATS) * NAIVE_MATURITY_PRICE_USDEM2_PER_BCH / SATS_PER_BCH
+            DERIVED_HEDGE_PAYOUT_ORACLE_UNITS - DERIVED_HEDGE_INPUT_ORACLE_UNITS + DERIVED_TOTAL_FEES_TO_MAKER_ORACLE_UNITS
         )
         expected_gain_oracleUnits_to_long_taker_at_redemption = UsdEM2Beta(
-            (DERIVED_LONG_PAYOUT_SATS - DERIVED_LONG_INPUT_SATS + TOTAL_FEES_TO_TAKER_SATS) * NAIVE_MATURITY_PRICE_USDEM2_PER_BCH / SATS_PER_BCH
+            DERIVED_LONG_PAYOUT_ORACLE_UNITS - DERIVED_LONG_INPUT_ORACLE_UNITS + DERIVED_TOTAL_FEES_TO_TAKER_ORACLE_UNITS
         )
         hedge_maker_contract = standard_maturation(standard_contract_funding(standard_contract_proposal(maker_side=Side.HEDGE)))
 
         # Hedge Maker
-        self.assertEqual(hedge_maker_contract.hedge_gain_oracleUnits, expected_gain_oracleUnits_to_hedge_maker_at_redemption)
-        self.assertEqual(hedge_maker_contract.maker_gain_oracleUnits, expected_gain_oracleUnits_to_hedge_maker_at_redemption)
+        self.assertAlmostEqual(hedge_maker_contract.hedge_gain_oracleUnits, expected_gain_oracleUnits_to_hedge_maker_at_redemption)
+        self.assertAlmostEqual(hedge_maker_contract.maker_gain_oracleUnits, expected_gain_oracleUnits_to_hedge_maker_at_redemption)
 
         # Long Taker
-        self.assertEqual(hedge_maker_contract.long_gain_oracleUnits, expected_gain_oracleUnits_to_long_taker_at_redemption)
-        self.assertEqual(hedge_maker_contract.taker_gain_oracleUnits, expected_gain_oracleUnits_to_long_taker_at_redemption)
+        self.assertAlmostEqual(hedge_maker_contract.long_gain_oracleUnits, expected_gain_oracleUnits_to_long_taker_at_redemption)
+        self.assertAlmostEqual(hedge_maker_contract.taker_gain_oracleUnits, expected_gain_oracleUnits_to_long_taker_at_redemption)
 
         # Long Maker / Hedge Taker
         expected_gain_oracleUnits_to_long_maker_at_redemption = UsdEM2Beta(
-            (DERIVED_LONG_PAYOUT_SATS - DERIVED_LONG_INPUT_SATS + TOTAL_FEES_TO_MAKER_SATS) * NAIVE_MATURITY_PRICE_USDEM2_PER_BCH / SATS_PER_BCH
+            DERIVED_LONG_PAYOUT_ORACLE_UNITS - DERIVED_LONG_INPUT_ORACLE_UNITS + DERIVED_TOTAL_FEES_TO_MAKER_ORACLE_UNITS
         )
         expected_gain_oracleUnits_to_hedge_taker_at_redemption = UsdEM2Beta(
-            (DERIVED_HEDGE_PAYOUT_SATS - DERIVED_HEDGE_INPUT_SATS + TOTAL_FEES_TO_TAKER_SATS) * NAIVE_MATURITY_PRICE_USDEM2_PER_BCH / SATS_PER_BCH
+            DERIVED_HEDGE_PAYOUT_ORACLE_UNITS - DERIVED_HEDGE_INPUT_ORACLE_UNITS + DERIVED_TOTAL_FEES_TO_TAKER_ORACLE_UNITS
         )
         long_maker_contract = standard_maturation(standard_contract_funding(standard_contract_proposal(maker_side=Side.LONG)))
 
         # Long Maker
-        self.assertEqual(long_maker_contract.long_gain_oracleUnits, expected_gain_oracleUnits_to_long_maker_at_redemption)
-        self.assertEqual(long_maker_contract.maker_gain_oracleUnits, expected_gain_oracleUnits_to_long_maker_at_redemption)
+        self.assertAlmostEqual(long_maker_contract.long_gain_oracleUnits, expected_gain_oracleUnits_to_long_maker_at_redemption)
+        self.assertAlmostEqual(long_maker_contract.maker_gain_oracleUnits, expected_gain_oracleUnits_to_long_maker_at_redemption)
 
         # Hedge Taker
-        self.assertEqual(long_maker_contract.hedge_gain_oracleUnits, expected_gain_oracleUnits_to_hedge_taker_at_redemption)
-        self.assertEqual(long_maker_contract.taker_gain_oracleUnits, expected_gain_oracleUnits_to_hedge_taker_at_redemption)
+        self.assertAlmostEqual(long_maker_contract.hedge_gain_oracleUnits, expected_gain_oracleUnits_to_hedge_taker_at_redemption)
+        self.assertAlmostEqual(long_maker_contract.taker_gain_oracleUnits, expected_gain_oracleUnits_to_hedge_taker_at_redemption)
 
     ######################
     # Sided versions of values
